#!/bin/bash
set -ex

# Update ubuntu-core and OS on an ubuntu system, assume checkbox-snappy
# is already installed.

# Setup
# -----
# Set the following in environment:
# DEVICE_IP=...
# HEXR_DEVICE_SECURE_ID=...
#
# for build description, use: 'ubuntu-core version: (.*)'

# convenience functions
#
SSH_OPTS="-o StrictHostKeyChecking=no -o UserKnownHostsFile=/dev/null"
_put() {
    scp $SSH_OPTS $1 ubuntu@${DEVICE_IP}:$2
}

_get() {
    scp $SSH_OPTS ubuntu@${DEVICE_IP}:$1 $2

}

_run() {
    ssh $SSH_OPTS ubuntu@${DEVICE_IP} sudo -iu ubuntu -- "$@"
}
_run_nofail() {
    ssh $SSH_OPTS ubuntu@${DEVICE_IP} sudo -iu ubuntu -- "$@" || /bin/true
}

# Start in a clean state
#
rm -rf ./artifacts
mkdir artifacts

_run_nofail sudo snap refresh ubuntu-core
_run snap list |grep ubuntu-core| awk '{print $1 " version: " $2}'
_run sudo apt-get update
_run sudo apt-get -y dist-upgrade
_run_nofail sudo reboot
sleep 30
until timeout 10 ssh -t ${SSH_OPTS} ubuntu@${DEVICE_IP} /bin/true
do
  echo Trying again...
  sleep 10
done
# PWL REPLACE THIS _run_nofail find /home/ubuntu/snap/checkbox-snappy/ -name submission*.xml -exec rm {} \\\;
CHECKBOX_OUTPUT_DIR=$(_run find /home/ubuntu/snap/checkbox-snappy -name checkbox-ng)
_run_nofail rm -f $CHECKBOX_OUTPUT_DIR/*
_run_nofail checkbox-snappy.smoke-test
SUBMISSION_FILE=$(_run find /home/ubuntu/snap/checkbox-snappy/ -name submission*.xml -not -name *junit*)
_run checkbox-snappy.checkbox submit --url https://certification.canonical.com/submissions/submit/ --secure_id ${HEXR_DEVICE_SECURE_ID} ${SUBMISSION_FILE}
_get $CHECKBOX_OUTPUT_DIR/* artifacts

